//  **** BEGIN LICENSE BLOCK ****
//  Copyright(c) 2005/2006 Adam Judson
//
//  PhotoMap
//  - display user contributed photos in a map
//
//  This program is free software; you can redistribute it and/or modify it under
//  the terms of the GNU General Public License as published by the Free
//  Software Foundation; either version 2 of the License, or (at your option)
//  any later version.
//
//  This program is distributed in the hope that it will be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
//  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
//  more details.
//
//  You should have received a copy of the GNU General Public License along with
//  this program; if not, write to the Free Software Foundation, Inc., 59 Temple
//  Place, Suite 330, Boston, MA 02111-1307 USA
//
//  **** END LICENSE BLOCK ****


//
// PhotoMapPreferences is the object we use to set and get things
// from the Moxilla Preferences system
//
// We don't listen for changes at this point.
//
function PhotoMapPreferences() {
   this.init();
}

PhotoMapPreferences.instance = function() {
   if (!PhotoMapPreferences.myInstance) {
      PhotoMapPreferences.myInstance = new PhotoMapPreferences();
   }
   return PhotoMapPreferences.myInstance;
}

PhotoMapPreferences.prototype = {
   PREFERENCES_ROOT   : "extensions.photomap.",
   PHOTOMAP_DEBUG     : "debug",

   PHOTOMAP_MAP_TYPE  : "map.type",
   PHOTOMAP_MAP_LIST  : "map.list",

   PHOTOMAP_GEOCODER_TYPE : "map.geocoder",

   PHOTOMAP_MAP_URL   : "map.url",
   PHOTOMAP_MAP_GOOGLE_KEY  : "map.google.key",
   PHOTOMAP_MAP_YAHOO_APPID : "map.yahoo.appid",

   PHOTOMAP_HOME_LAT  : "home.lat",
   PHOTOMAP_HOME_LON  : "home.lon",
   PHOTOMAP_HOME_ZOOM : "home.zoom",

   PHOTOMAP_PHOTO_SERVICE_TYPE   : "photo.serviceType",
   PHOTOMAP_PHOTO_FLICKR_ID      : "photo.flickr.id",
   PHOTOMAP_PHOTO_FLICKR_SECRET  : "photo.flickr.secret",
   PHOTOMAP_PHOTO_FLICKR_NEW_ACCOUNT_URL : "photo.flickr.new.account.url",
   PHOTOMAP_PHOTO_FLICKR_TOKEN   : "photo.flickr.token",

   PHOTOMAP_PHOTO_23_NEW_ACCOUNT_URL : "photo.23.new.account.url",
   PHOTOMAP_PHOTO_23_TOKEN           : "photo.23.token",

   PHOTOMAP_PHOTO_SEASON         : "photo.season",
   PHOTOMAP_PHOTO_TOD            : "photo.time.of.day",
   PHOTOMAP_PHOTO_POV            : "photo.pov",
   PHOTOMAP_PHOTO_PHOTOS_PER_MAP : "photo.photos.per.map",

   PHOTOMAP_EARTH_SERVER_PORT    : "earth.server.port",
   PHOTOMAP_EARTH_SERVER_FORCE_DISPLAY : "earth.server.force.display",

   PHOTOMAP_PHOTO_MAX_TXN_PER_SECOND  : "photo.max.txn.per.second.",
   PHOTOMAP_PHOTO_MAX_OUTSTANDING_TXN : "photo.max.outstanding.txn.",


   init : function() {
      // connected to the preferences system etc.
      this.root = Components.classes["@mozilla.org/preferences-service;1"].
                     getService(Components.interfaces.nsIPrefService).
                     getBranch(this.PREFERENCES_ROOT);
   },

   getBool : function(key) {
      return this.root.getBoolPref(key);
   },

   getString : function(value) {
      return this.root.getCharPref(value);
   },

   setString : function(key, value) {
      return this.root.setCharPref(key, value);
   },

   removeString : function(key) {
      PhotoMapUtils.log("Removing string: " + key);
      this.root.clearUserPref(key);
   },

   isDebug : function() {
      return this.getString(this.PHOTOMAP_DEBUG) == "true";
   },

   getMapType : function() {
      return this.getString(this.PHOTOMAP_MAP_TYPE);
   },

   setMapType : function(type) {
      return this.setString(this.PHOTOMAP_MAP_TYPE, type);
   },

   getMapsList : function() {
      var list = this.getString(this.PHOTOMAP_MAP_LIST);
      return list.split(",");
   },

   getHome : function() {
      return {lat : this.getString(this.PHOTOMAP_HOME_LAT), lon : this.getString(this.PHOTOMAP_HOME_LON)};
   },

   setHome : function(point) {
      if (point) {
         if (point.lat) {
            this.setString(this.PHOTOMAP_HOME_LAT, point.lat);
         }
         if (point.lon) {
            this.setString(this.PHOTOMAP_HOME_LON, point.lon);
         }
      }
   },

   getHomeZoom : function() {
      return this.getString(this.PHOTOMAP_HOME_ZOOM);
   },

   setHomeZoom : function(zoom) {
      if (zoom && (zoom >= 0 && zoom <= 10)) {
         this.setString(this.PHOTOMAP_HOME_ZOOM, zoom);
      } else {
         window.alert("Bad zoom: " + zoom);
      }
   },

   getMapURL : function() {
      return this.getString(this.PHOTOMAP_MAP_URL);
   },

   getGoogleKey : function() {
      return this.getString(this.PHOTOMAP_MAP_GOOGLE_KEY);
   },

   getYahooAppid: function() {
      return this.getString(this.PHOTOMAP_MAP_YAHOO_APPID);
   },

   getFlickrId : function() {
      return this.getString(this.PHOTOMAP_PHOTO_FLICKR_ID);
   },

   getFlickrSecret : function(provider) {
      if (provider == "flickr") {
         return this.getString(this.PHOTOMAP_PHOTO_FLICKR_SECRET);
      } else {
         return "";
      }
   },

   getNewPhotoAccountUrl : function(provider) {
      if (provider == "flickr") {
         return this.getString(this.PHOTOMAP_PHOTO_FLICKR_NEW_ACCOUNT_URL);
      } else {
         return this.getString(this.PHOTOMAP_PHOTO_23_NEW_ACCOUNT_URL);
      }
   },

   setFlickrToken : function(token, provider) {
      if (provider == "flickr") {
         this.setString(this.PHOTOMAP_PHOTO_FLICKR_TOKEN, token);
      } else {
         this.setString(this.PHOTOMAP_PHOTO_23_TOKEN, token);
      }         
   },

   getFlickrToken : function(provider) {
      if (provider == "flickr") {
         return this.getString(this.PHOTOMAP_PHOTO_FLICKR_TOKEN);
      } else {
         return this.getString(this.PHOTOMAP_PHOTO_23_TOKEN);
      }
   },

   getPhotoServiceType : function() {
      return this.getString(this.PHOTOMAP_PHOTO_SERVICE_TYPE);
   },

   getPhotoSeason : function() {
      return this.getString(this.PHOTOMAP_PHOTO_SEASON);
   },

   setPhotoSeason : function(season) {
      if (season) {
         this.setString(this.PHOTOMAP_PHOTO_SEASON, season);
      }
   },

   getPhotoTimeOfDay : function() {
      return this.getString(this.PHOTOMAP_PHOTO_TOD);
   },

   setPhotoTimeOfDay : function(timeOfDay) {
      if (timeOfDay) {
         this.setString(this.PHOTOMAP_PHOTO_TOD, timeOfDay);
      }
   },

   getPhotoPOV : function() {
      return this.getString(this.PHOTOMAP_PHOTO_POV);
   },

   setPhotoPOV : function(pov) {
      if (pov) {
         this.setString(this.PHOTOMAP_PHOTO_POV, pov);
      }
   },

   getEarthServerPort : function() {
      return this.getString(this.PHOTOMAP_EARTH_SERVER_PORT);
   },

   getPhotosPerMap : function() {
      return this.getString(this.PHOTOMAP_PHOTO_PHOTOS_PER_MAP);
   },

   setPhotosPerMap : function(number) {
      if (number) {
         this.setString(this.PHOTOMAP_PHOTO_PHOTOS_PER_MAP, number);
      }
   },

   getServerForceDisplay : function() {
      return this.getBool(this.PHOTOMAP_EARTH_SERVER_FORCE_DISPLAY);
   },

   getGeocoderType : function() {
      return this.getString(this.PHOTOMAP_GEOCODER_TYPE);
   },

   getMaxTxnPerSecond : function(provider) {
      return this.getString(this.PHOTOMAP_PHOTO_MAX_TXN_PER_SECOND + provider);
   },

   getMaxOutstandingTxn : function(provider) {
      return this.getString(this.PHOTOMAP_PHOTO_MAX_OUTSTANDING_TXN + provider);
   }
}

